@@ -14,7 +14,7 @@ use base qw(Apache::Session);
 use Lemonldap::NG::Common::Apache::Session::Store;
 use Lemonldap::NG::Common::Apache::Session::Lock;
 
-our $VERSION = '1.4.8';
+our $VERSION = '1.4.9';
 
 sub _load {
     my $backend = shift;
@@ -322,7 +322,7 @@ sub _LDAPGKFAS {
         attrs  => [ 'cn', 'description' ],
     );
     $ldap->unbind();
-    $ldap->disconect();
+    $ldap->disconnect();
     Apache::Session::Store::LDAP->logError($msg) if ( $msg->code );
     my %res;
     foreach my $entry ( $msg->entries ) {
