@@ -14,7 +14,7 @@ use MIME::Base64;
 use Digest::MD5 qw(md5);
 use bytes;
 
-our $VERSION = '1.2.3';
+our $VERSION = '1.4.0';
 
 our $msg;
 
@@ -59,7 +59,7 @@ sub encrypt {
     my $l = bytes::length($data) % 16;
     $data .= "\0" x ( 16 - $l ) unless ( $l == 0 );
 
-    eval { $data = encode_base64( $self->_getCipher->encrypt($data) ); };
+    eval { $data = encode_base64( $self->_getCipher->encrypt($data), '' ); };
     if ($@) {
         $msg = "Crypt::Rijndael error : $@";
         return undef;
@@ -80,6 +80,7 @@ sub decrypt {
     $data =~ s/%2B/\+/ig;
     $data =~ s/%2F/\//ig;
     $data =~ s/%3D/=/ig;
+    $data =~ s/%0A/\n/ig;
     eval { $data = $self->_getCipher->decrypt( decode_base64($data) ); };
     if ($@) {
         $msg = "Crypt::Rijndael error : $@";
